@@ -103,7 +103,7 @@ sub inherit
         if (! exists($$HERITAGE{$package}) ||
             ! exists($$HERITAGE{$package}[0]{$$self}))
         {
-            return (undef);
+            return;
         }
 
         my @objs;
@@ -273,5 +273,5 @@ sub inherit
 
 
 # Ensure correct versioning
-my $VERSION = 1.45;
-($Object::InsideOut::VERSION == 1.45) or die("Version mismatch\n");
+my $VERSION = 1.46;
+($Object::InsideOut::VERSION == 1.46) or die("Version mismatch\n");
